;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;      OPEN PEER REVIEW MODEL      ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

globals [
  publication-bias
  reviewing-expenses
  published-quality
  resource-dist
  overrating-factor
  underrating-factor
  avg-publication-bias
  avg-rev-expenses
  avg-published-quality
]

turtles-own [
  resources
  ranking-position
  expected-quality
  role
  unreliable?
  submission-quality
  should-have-been-published?
  boundary-value?
  evaluated-submission-quality
  published?
  submission-resource-spent
  publication-resource-gain
  review-resource-spent
  guess-author-productivity
  n-publications
  positive-memory
  negative-memory
]

;;;;;;;;;;;;;;;;;;;;;;;; INITIALIZATION ;;;;;;;;;;;;;;;;;;;;;;;;


to setup
  clear-all
  ask patches [set pcolor white]
  ask n-of n-scientists patches [
    sprout 1 [
      set color gray
      set shape "circle"
      set resources initial-resources
      set role "none"
      set unreliable? false
      set n-publications 0
      set positive-memory []
      set negative-memory []
      set label precision resources 2
      set label-color black
    ]
  ]
  set underrating-factor 1 - unreliable-excursion / 100
  set overrating-factor 1 + unreliable-excursion / 100
  if status? [set resource-dist []]
  reset-ticks
end

;;;;;;;;;;;;;;;;;;;;;;;; SIMULATION ;;;;;;;;;;;;;;;;;;;;;

to go
  tick
  clear-links
  update-scientists
  ask turtles [set role "none"]
  set-reviewers
  set-authors
  match-scientists
  submit
  review
  select-publications
  update-memory
  indexes
end

to update-scientists
  ask turtles [
    set published? false
    set unreliable? false
    set resources resources + round-resource-gain + publication-resource-gain - submission-resource-spent - review-resource-spent
    set expected-quality (velocity * resources) / (velocity * resources + 1)
    set submission-resource-spent 0
    set review-resource-spent 0
    set publication-resource-gain 0
    set label precision resources 2
    set color gray
  ]
  if status? [
    set resource-dist sort [resources] of turtles
  ]

  ;;career ranking
  (foreach (range count turtles) (sort-on [ resources ] turtles) [ [i scientist] ->
    ask scientist [ set ranking-position i ]
  ])
end

to set-authors
  ask turtles with [role != "reviewer"] [
    set role "author"
    set color violet
  ]
end

to set-reviewers
  ask n-of (n-scientists / 2) turtles [
    set role "reviewer"
    set color red
  ]
  if bias? [
    ; *** this means that non reviewers can be unreliable too. Is that correct?
    ask n-of (n-scientists * proportion-unreliable) turtles [
      set unreliable? true
      set color red + 4
    ]
  ]
end

to match-scientists
  ask turtles with [role = "author"] [
    create-link-with one-of turtles with [role = "reviewer" and not any? my-links ]
  ]
end

to submit
  ask turtles with [role = "author"] [
    set submission-quality random-normal expected-quality (expected-quality * author-bias-factor)
    set submission-resource-spent (resources * author-spent-factor-for-article)
  ]
end

to review
  ask turtles with [role = "author"] [
    let author self
    let reviewer one-of link-neighbors
    ask reviewer [
      set review-resource-spent 0.5 * resources * (1 + ([submission-quality] of author - expected-quality)) ;; in open peer review systems review is always costly, even when it's unreliable
      (ifelse
        unreliable? [ ifelse one-of [ true false ] [ overrate ] [ underrate ] ]
        status? and reviewer-in-bottom-quarter? and ([ resources ] of author > resources * multiplier) [ overrate ]
        member? author positive-memory [ overrate ]
        member? author negative-memory [ underrate ]
        [ rate-correctly ]
      )
      if guess-author-productivity < 0 [ set guess-author-productivity 0 ]
    ]
    set evaluated-submission-quality (velocity * [guess-author-productivity] of reviewer) / (velocity * [guess-author-productivity] of reviewer + 1)
  ]
end

to-report reviewer-in-bottom-quarter? ; turtle reporter
  report resources < item (length resource-dist / 4 - 1) resource-dist
end

to rate-correctly
  set guess-author-productivity random-normal ([resources] of myself) ([resources] of myself * reliable-evaluation-bias-factor)
end

to overrate
  set guess-author-productivity random-normal ([resources] of myself * overrating-factor) ([resources] of myself * overrating-factor *
    reliable-evaluation-bias-factor)
end

to underrate
  set guess-author-productivity random-normal ([resources] of myself * underrating-factor) ([resources] of myself * underrating-factor *
    reliable-evaluation-bias-factor)
end

to update-memory
  ask turtles with [role = "author"] [
    let reviewer one-of link-neighbors
    set positive-memory remove reviewer positive-memory
    set negative-memory remove reviewer negative-memory
    ifelse published? [
      set positive-memory fput reviewer positive-memory
    ] [
      set negative-memory fput reviewer negative-memory
    ]
  ]
end

to select-publications

  let authors turtles with [ role = "author" ]

  (foreach (range count authors) (sort-on [ (- evaluated-submission-quality) ] authors) [ [i author] ->
    ask author [
      set published? (i < tot-publications)
      if published? [
        set color yellow
        set n-publications n-publications + 1
      ]
    ]
  ])

  let published-authors sort-on [ ranking-position ] authors with [ published? ]
  (foreach (range length published-authors) published-authors [ [i author] ->
    ask author [
      let limiter (i / (tot-publications - 1)) * (publication-resource-gain-factor - 1)
      set publication-resource-gain resources * (publication-resource-gain-factor - limiter)
    ]
  ])

  ;; computing the optimal list of publications:
  let median-value median [submission-quality] of authors
  (foreach (range count authors) (sort-on [ (- submission-quality) ] authors) [ [i author] ->
    ask author [
      set should-have-been-published? (i < tot-publications)
      set boundary-value? (submission-quality = median-value)
    ]
  ])

end

to indexes
  ; calculate publication bias
  let unpub-errors count turtles with [ role = "author" and not published? and should-have-been-published? and not boundary-value? ]
  set publication-bias unpub-errors / tot-publications * 100 ; % of number of published submissions
  set-current-plot "Publication bias"
  set-current-plot-pen "errors"
  plot publication-bias

  ; calculate reviewing expenses
  let rev-spent sum [review-resource-spent] of turtles with [role = "reviewer"]
  let aut-spent sum [submission-resource-spent] of turtles with [role = "author"]
  set reviewing-expenses rev-spent / aut-spent * 100 ; percentage
  set-current-plot "Reviewing expenses"
  set-current-plot-pen "default"
  plot reviewing-expenses

  ; calculate published quality
  set published-quality mean [submission-quality] of turtles with [ published? ]

  ; compute moving average values for output indexes
  if ticks > 1400 [
    set avg-publication-bias (publication-bias + (ticks - 1400 - 1) * avg-publication-bias) / (ticks - 1400)
    set avg-rev-expenses (reviewing-expenses + (ticks - 1400 - 1) * avg-rev-expenses) / (ticks - 1400)
    set avg-published-quality (published-quality + (ticks - 1400 - 1) * avg-published-quality) / (ticks - 1400)
  ]
end

to-report tot-publications
  report count turtles with [role = "author"] * publication-rate
end
@#$#@#$#@
GRAPHICS-WINDOW
25
135
316
427
-1
-1
8.6
1
10
1
1
1
0
1
1
1
-16
16
-16
16
0
0
1
ticks
30.0

SLIDER
25
85
197
118
n-scientists
n-scientists
12
300
240.0
12
1
NIL
HORIZONTAL

BUTTON
25
30
88
63
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
95
30
158
63
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
165
30
228
63
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
340
185
492
245
round-resource-gain
1.0
1
0
Number

INPUTBOX
341
122
493
182
initial-resources
0.0
1
0
Number

INPUTBOX
340
255
492
315
publication-rate
0.25
1
0
Number

INPUTBOX
340
320
492
380
publication-resource-gain-factor
1.5
1
0
Number

TEXTBOX
30
480
180
498
||| : author
11
115.0
1

TEXTBOX
95
480
245
498
||| : reviewer unreliable
11
15.0
1

TEXTBOX
200
495
350
513
||| : published
11
45.0
1

PLOT
780
80
1245
345
Publication bias
NIL
%
0.0
10.0
0.0
50.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""
"errors" 1.0 0 -2674135 true "" ""

PLOT
780
350
1245
620
Reviewing expenses
NIL
NIL
0.0
10.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

TEXTBOX
220
480
370
498
||| : reviewer reliable
11
19.0
1

INPUTBOX
780
10
855
70
velocity
0.1
1
0
Number

INPUTBOX
858
10
993
70
author-bias-factor
0.1
1
0
Number

INPUTBOX
998
10
1148
70
author-spent-factor-for-article
1.0
1
0
Number

INPUTBOX
1150
10
1245
70
reliable-evaluation-bias-factor
0.1
1
0
Number

SLIDER
325
385
480
418
unreliable-excursion
unreliable-excursion
10
90
90.0
10
1
NIL
HORIZONTAL

MONITOR
340
440
417
485
underrating
underrating-factor
2
1
11

MONITOR
340
495
420
540
overrating
overrating-factor
2
1
11

TEXTBOX
220
35
370
61
NIL
12
14.0
1

BUTTON
237
25
332
58
go x 1500
repeat 1500 [go]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
560
115
685
175
proportion-unreliable
0.25
1
0
Number

SWITCH
381
25
484
58
bias?
bias?
0
1
-1000

SWITCH
382
63
484
96
status?
status?
1
1
-1000

SLIDER
535
30
707
63
multiplier
multiplier
0
5
2.0
1
1
NIL
HORIZONTAL

@#$#@#$#@
## NOTES

This ABM looks at the effect of multiple reviewers and their behavior on the quality and efficiency of peer review. It models a community of scientists who alternatively act as "author" or "reviewer" at each turn. Authors' task is to submit an article and have it published, while each reviewer evaluate one submitted article.

Reviewers are influenced by the outcome of their own previous submission as authors, independent of the identity of the reviewers they had been assigned to. In cases in which their past submissions had been accepted, they provide reliable opinions when selected as reviewers. In cases of past rejection, they reciprocate negatively by providing biased opinion on the quality of author submissions.

Number of reviewers assigned to each submitted article can be manipulated through the "n-reviewers" global variable.

Resources are needed both to submit and review an article. Each scientist has a
variable set of resources, which are initially homogeneously distributed. At each tick the agents are endowed with a fixed amount of resources, equal for all. Plus, they cumulate resources according to their publication score.

The quality of author submissions depends on scientist’s resources. The expected submission quality of an author.

The chance of being published is determined by the average evaluation score assigned by reviewers. Depending on the reviewers’ opinion, only a fixed number of submissions are published at each turn. If not published, authors lose all the resources invested for submitting. Successful publication multiplies author resources for a mutiplier value.

When selected as reviewers, scientists invest a given amount of resources for
reviewing and simultaneously lose the opportunity to publish. Reviewing expenses grow linearly with the quality of authors’ submissions. Reviewing expenses increase proportionally on scientist productivity.

For more details on the model, see references below.


## CREDITS AND REFERENCES

F. Bianchi & F. Squazzoni, "Is Three Better Than One? Simulating the Effect of Multiple Reviewer Selection on the Quality and Efficiency of Peer Review", Proceedings of the Winter Simulation Conference  2015, Dec. 6-9, Huntington Beach (CA), forthcoming (exp. 2016).

For other work related to a simpler version of the model, see:

F. Squazzoni & C. Gandelli (2012), “Saint Matthew Strikes Again. An Agent-Based Model of Peer Review and the Scientific Community Structures”, Journal of Informetrics 6:265–275.

F. Squazzoni & C. Gandelli (2013), “Opening the Black Box of Peer Review. An Agent-Based Model of Scientist Behaviour”, Journal of Artificial Societies and Social Simulation 16(2)3. http://jasss.soc.surrey.ac.uk/16/2/3.html

For any contact, please write to federico.bianchi1@unimi.it
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="open" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>publication-bias</metric>
    <metric>reviewing-expenses</metric>
    <metric>published-quality</metric>
    <metric>avg-publication-bias</metric>
    <metric>avg-rev-expenses</metric>
    <metric>avg-published-quality</metric>
    <enumeratedValueSet variable="n-scientists">
      <value value="240"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-resources">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="round-resource-gain">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-rate">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="publication-resource-gain-factor">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unreliable-excursion">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="velocity">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="author-spent-factor-for-article">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reliable-evaluation-bias-factor">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bias?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="status?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="multiplier">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="proportion-unreliable">
      <value value="0.25"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
1
@#$#@#$#@
